﻿//
// WpfCSarp
//
// Copyright (c) 2016 http://www.curict.com
// This software is released under the MIT License, see LICENSE.txt.
//

using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;

namespace WpfCSharp
{
    public class MainWindowViewModel : INotifyDataErrorInfo
    {
        private Dictionary<string, string> _errorMessageDict = new Dictionary<string, string>();
        private string _text1;
        private string _text2;


        public MainWindowViewModel ()
        {
            this.Text1 = string.Empty;
            this.Text2 = string.Empty;
        }


        public string Text1
        {
            get
            {
                return _text1;
            }
            set
            {
                _text1 = value;
                if (string.IsNullOrEmpty(_text1))
                {
                    _errorMessageDict["Text1"] = "テキストボックスが空です。";
                    ErrorsChanged?.Invoke(this, new DataErrorsChangedEventArgs("Text1"));
                }
                else
                {
                    _errorMessageDict["Text1"] = string.Empty;
                    ErrorsChanged?.Invoke(this, new DataErrorsChangedEventArgs("Text1"));
                }
            }
        }

        public string Text2
        {
            get
            {
                return _text2;
            }
            set
            {
                _text2 = value;
                if (string.IsNullOrEmpty(_text2))
                {
                    _errorMessageDict["Text2"] = "テキストボックスが空です。";
                    ErrorsChanged?.Invoke(this, new DataErrorsChangedEventArgs("Text2"));
                }
                else
                {
                    _errorMessageDict["Text2"] = string.Empty;
                    ErrorsChanged?.Invoke(this, new DataErrorsChangedEventArgs("Text2"));
                }
            }
        }


        public bool HasErrors
        {
            get
            {
                foreach (KeyValuePair<string, string> pair in _errorMessageDict)
                {
                    if (!string.IsNullOrWhiteSpace(pair.Value))
                    {
                        return true;
                    }
                }
                return false;
            }
        }

        public event EventHandler<DataErrorsChangedEventArgs> ErrorsChanged;


        public IEnumerable GetErrors(string propertyName)
        {
            if (!_errorMessageDict.ContainsKey(propertyName))
            {
                return null;
            }
            string errorMessage = _errorMessageDict[propertyName];

            if (string.IsNullOrEmpty(errorMessage))
            {
                return null;
            }

            return new string[] { errorMessage };
        }
    }
}
